"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const architect_1 = require("@angular-devkit/architect");
const fs_1 = require("fs");
const glob = require("glob");
const path = require("path");
const stylelint_1 = require("stylelint");
function _run(options, context) {
    return __awaiter(this, void 0, void 0, function* () {
        const systemRoot = context.workspaceRoot;
        const { stylelintConfig, format: formatter, fix, force, silent } = options;
        const config = stylelintConfig
            ? JSON.parse(fs_1.readFileSync(path.resolve(systemRoot, stylelintConfig), "utf-8"))
            : undefined;
        const result = yield stylelint_1.lint({
            config,
            formatter,
            configBasedir: systemRoot,
            files: getFilesToLint(systemRoot, options),
            fix
        });
        if (!silent) {
            if (result.errored) {
                context.logger.error("Lint errors found in the listed files.");
            }
            else {
                context.logger.info("All files pass linting.");
            }
            const errored = result.results.filter(x => x.errored);
            if (errored.length) {
                context.logger.info(stylelint_1.formatters.string(errored));
            }
        }
        return {
            success: force || !result.errored
        };
    });
}
function getFilesToLint(root, options) {
    const { files, exclude: ignore } = options;
    return files
        .map(file => glob.sync(file, { cwd: root, ignore, nodir: true }))
        .reduce((prev, curr) => prev.concat(curr), []);
}
exports.default = architect_1.createBuilder(_run);
//# sourceMappingURL=index.js.map